The electricity, gas and water supplies are in order and well-maintained. | OiRA

Help

1. Preparación
2. Implicación
3. Identificación + Evaluación
   1. 1 Commercial manned guarding
      1. 1.1 Work environment (site related)
         1. 1.1.1 Slips, trips and falls are prevented.
         2. 1.1.2 Collisions, bumps, and jamming are prevented.
         3. 1.1.3 The electricity, gas and water supplies are in order and well-maintained.
         4. 1.1.4 Exposure to noise is prevented or controlled.
         5. 1.1.5 Exposure to chemical substances is prevented or controlled.
         6. 1.1.6 Exposure to biological substances is prevented or controlled.
         7. 1.1.7 Exposure to radiation is prevented or controlled.
         8. 1.1.8 Risks from ambient factors are prevented.
         9. 1.1.9 All necessary facilities are available and well maintained.
      2. 1.2 Fire prevention and emergency procedures
   2. Ω Riesgos añadidos (por Ud)
   - Sin respuesta
   - Pospuesto
   - OK
   - Atención
4. Plan de acción
5. Informe
6. Grado de cumplimentación 0%

Help

## The electricity, gas and water supplies are in order and well-maintained.

Sí No No procede

### Información

Ensure that the electrical system, as well as the gas and water supplies are safe. Some examples: all the exposed conductive parts are connected to the earthing system; all safety devices and switches are in place and they work well; there are measures in place to protect electrical equipment from water; …

- The electricity, gas and water supplies at the client company must comply with the relevant safety regulations and be maintained by competent people in accordance with regulations.
- There should be restricted access to electricity, gas and water premises.

### Recursos

#### Referencias legales y de políticas

- 89/391/CEE Implementing measures to improve the health and safety of workers (framework directive).
- 89/654/EEC Directive on the minimum safety and health requirements for the workplace.
- 2006/95/EC Directive on the harmonisation of the laws of Member States relating to electrical equipment designed for use within certain voltage limits.

#### Recursos adicionales para evaluar el riesgo

- Lorem ipsum dolor sit.pdf
- Amet consectetuer.pdf

Comentarios

Scroll to top
Back

## 2014-01-05-the-electricity-gas-and-water-supplies-are-in-order-and-well-maintained.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More